@@ -10,6 +10,8 @@
 #' @param wts Weights to use in estimation
 #' @param check Use "standardize" to see standardized coefficient estimates. Use "stepwise-backward" (or "stepwise-forward", or "stepwise-both") to apply step-wise selection of variables in estimation.
 #' @param data_filter Expression entered in, e.g., Data > View to filter the dataset in Radiant. The expression should be a string (e.g., "price > 10000")
+#' @param arr Expression to arrange (sort) the data on (e.g., "color, desc(price)")
+#' @param rows Rows to select from the specified dataset
 #' @param envir Environment to extract data from
 #'
 #' @return A list with all variables defined in mnl as an object of class mnl
@@ -29,12 +31,9 @@
 #' @seealso \code{\link{plot.model.predict}} to plot prediction output
 #'
 #' @export
-mnl <- function(
-  dataset, rvar, evar, lev = "", int = "",
-  wts = "None", check = "",
-  data_filter = "", envir = parent.frame()
-) {
-
+mnl <- function(dataset, rvar, evar, lev = "", int = "",
+                wts = "None", check = "", data_filter = "",
+                arr = "", rows = NULL, envir = parent.frame()) {
   if (rvar %in% evar) {
     return("Response variable contained in the set of explanatory variables.\nPlease update model specification." %>%
       add_class("mnl"))
@@ -42,7 +41,7 @@ mnl <- function(
 
   vars <- c(rvar, evar)
 
-  if (radiant.data::is_empty(wts, "None")) {
+  if (is.empty(wts, "None")) {
     wts <- NULL
   } else if (is_string(wts)) {
     wtsname <- wts
@@ -50,9 +49,9 @@ mnl <- function(
   }
 
   df_name <- if (is_string(dataset)) dataset else deparse(substitute(dataset))
-  dataset <- get_data(dataset, vars, filt = data_filter, envir = envir)
+  dataset <- get_data(dataset, vars, filt = data_filter, arr = arr, rows = rows, envir = envir)
 
-  if (!radiant.data::is_empty(wts)) {
+  if (!is.empty(wts)) {
     if (exists("wtsname")) {
       wts <- dataset[[wtsname]]
       dataset <- select_at(dataset, .vars = base::setdiff(colnames(dataset), wtsname))
@@ -76,20 +75,26 @@ mnl <- function(
     if (is.factor(rv)) {
       lev <- levels(rv)[1]
     } else {
-      lev <- as.character(rv) %>% as.factor() %>% levels() %>% .[1]
+      lev <- as.character(rv) %>%
+        as.factor() %>%
+        levels() %>%
+        .[1]
     }
   }
 
   ## re-leveling the
-  dataset[[rvar]] <- dataset[[rvar]] %>% as.factor() %>% relevel(ref = lev)
+  dataset[[rvar]] <- dataset[[rvar]] %>%
+    as.factor() %>%
+    relevel(ref = lev)
   lev <- levels(dataset[[1]])
 
   vars <- ""
-  var_check(evar, colnames(dataset)[-1], int) %>% {
-    vars <<- .$vars
-    evar <<- .$ev
-    int <<- .$intv
-  }
+  var_check(evar, colnames(dataset)[-1], int) %>%
+    {
+      vars <<- .$vars
+      evar <<- .$ev
+      int <<- .$intv
+    }
 
   ## add minmax attributes to data
   mmx <- minmax(dataset)
@@ -115,12 +120,10 @@ mnl <- function(
     mnl_input <- list(formula = form_upper, weights = wts, data = dataset, model = TRUE, trace = FALSE)
     model <- do.call(nnet::multinom, mnl_input) %>%
       step(k = 2, scope = list(lower = form_lower), direction = "backward")
-
   } else if ("stepwise-forward" %in% check) {
     mnl_input <- list(formula = form_lower, weights = wts, data = dataset, model = TRUE, trace = FALSE)
     model <- do.call(nnet::multinom, mnl_input) %>%
       step(k = 2, scope = list(upper = form_upper), direction = "forward")
-
   } else if ("stepwise-both" %in% check) {
     mnl_input <- list(formula = form_lower, weights = wts, data = dataset, model = TRUE, trace = FALSE)
     model <- do.call(nnet::multinom, mnl_input) %>%
@@ -132,7 +135,9 @@ mnl <- function(
     model <- do.call(nnet::multinom, mnl_input)
   }
 
-  coeff <- tidy(model) %>% na.omit() %>% as.data.frame()
+  coeff <- tidy(model) %>%
+    na.omit() %>%
+    as.data.frame()
 
   ## needed for prediction if standardization or centering is used
   if ("standardize" %in% check || "center" %in% check) {
@@ -195,13 +200,14 @@ mnl <- function(
 #' @importFrom car linearHypothesis
 #'
 #' @export
-summary.mnl <- function(
-  object, sum_check = "", conf_lev = .95,
-  test_var = "", dec = 3, ...
-) {
-
-  if (is.character(object)) return(object)
-  if (class(object$model)[1] != "multinom") return(object)
+summary.mnl <- function(object, sum_check = "", conf_lev = .95,
+                        test_var = "", dec = 3, ...) {
+  if (is.character(object)) {
+    return(object)
+  }
+  if (class(object$model)[1] != "multinom") {
+    return(object)
+  }
 
   if (any(grepl("stepwise", object$check))) {
     step_type <- if ("stepwise-backward" %in% object$check) {
@@ -218,9 +224,15 @@ summary.mnl <- function(
 
   cat("Multinomial logistic regression (MNL)")
   cat("\nData                 :", object$df_name)
-  if (!radiant.data::is_empty(object$data_filter)) {
+  if (!is.empty(object$data_filter)) {
     cat("\nFilter               :", gsub("\\n", "", object$data_filter))
   }
+  if (!is.empty(object$arr)) {
+    cat("\nArrange              :", gsub("\\n", "", object$arr))
+  }
+  if (!is.empty(object$rows)) {
+    cat("\nSlice                :", gsub("\\n", "", object$rows))
+  }
   cat("\nResponse variable    :", object$rvar)
   cat("\nBase level           :", object$lev[1], "in", object$rvar)
   cat("\nExplanatory variables:", paste0(object$evar, collapse = ", "), "\n")
@@ -259,7 +271,7 @@ summary.mnl <- function(
   ## pseudo R2 (likelihood ratio) - http://en.wikipedia.org/wiki/Logistic_Model
   mnl_fit %<>% mutate(r2 = (null.deviance - deviance) / null.deviance) %>%
     round(dec)
-  if (!radiant.data::is_empty(object$wts, "None") && (length(unique(object$wts)) > 2 || min(object$wts) >= 1)) {
+  if (!is.empty(object$wts, "None") && (length(unique(object$wts)) > 2 || min(object$wts) >= 1)) {
     nobs <- sum(object$wts)
     mnl_fit$BIC <- round(-2 * mnl_fit$logLik + ln(nobs) * with(mnl_fit, edf), dec)
   } else {
@@ -268,7 +280,9 @@ summary.mnl <- function(
 
   # ## chi-squared test of overall model fit (p-value) - http://www.ats.ucla.edu/stat/r/dae/logit.htm
   chi_pval <- with(mnl_fit, pchisq(null.deviance - deviance, edf - 1, lower.tail = FALSE))
-  chi_pval %<>% {if (. < .001) "< .001" else round(., dec)}
+  chi_pval %<>% {
+    if (. < .001) "< .001" else round(., dec)
+  }
 
   cat("\nPseudo R-squared:", mnl_fit$r2)
   cat(paste0("\nLog-likelihood: ", mnl_fit$logLik, ", AIC: ", mnl_fit$AIC, ", BIC: ", mnl_fit$BIC))
@@ -298,7 +312,9 @@ summary.mnl <- function(
 
       if ("confint" %in% sum_check) {
         ci_tab %T>%
-          {.$`+/-` <- (.$High - .$coefficient)} %>%
+          {
+            .$`+/-` <- (.$High - .$coefficient)
+          } %>%
           format_df(dec) %>%
           set_colnames(c("  ", " ", "coefficient", ci_perc[1], ci_perc[2], "+/-")) %>%
           print(row.names = FALSE)
@@ -312,7 +328,7 @@ summary.mnl <- function(
       cat("RRRs were not calculated\n")
     } else {
       rrrlab <- if ("standardize" %in% object$check) "std RRR" else "RRR"
-      ci_tab[,-c(1, 2)] <- exp(ci_tab[,-c(1, 2)])
+      ci_tab[, -c(1, 2)] <- exp(ci_tab[, -c(1, 2)])
       ci_tab[!grepl("(Intercept)", ci_tab[[2]]), ] %>%
         format_df(dec) %>%
         set_colnames(c("  ", "", rrrlab, ci_perc[1], ci_perc[2])) %>%
@@ -321,7 +337,7 @@ summary.mnl <- function(
     }
   }
 
-  if (!radiant.data::is_empty(test_var)) {
+  if (!is.empty(test_var)) {
     if (any(grepl("stepwise", object$check))) {
       cat("Model comparisons are not conducted when Stepwise has been selected.\n")
     } else {
@@ -393,15 +409,18 @@ summary.mnl <- function(
 #' @seealso \code{\link{predict.mnl}} to generate predictions
 #' @seealso \code{\link{plot.model.predict}} to plot prediction output
 #'
+#' @importFrom rlang .data
+#'
 #' @export
-plot.mnl <- function(
-  x, plots = "coef", conf_lev = .95,
-  intercept = FALSE, nrobs = -1,
-  shiny = FALSE, custom = FALSE, ...
-) {
-
-  if (is.character(x) || !inherits(x$model, "multinom")) return(x)
-  if (radiant.data::is_empty(plots[1])) return("Please select a mnl regression plot from the drop-down menu")
+plot.mnl <- function(x, plots = "coef", conf_lev = .95,
+                     intercept = FALSE, nrobs = -1,
+                     shiny = FALSE, custom = FALSE, ...) {
+  if (is.character(x) || !inherits(x$model, "multinom")) {
+    return(x)
+  }
+  if (is.empty(plots[1])) {
+    return("Please select a mnl regression plot from the drop-down menu")
+  }
 
   model <- x$model$model
   rvar <- x$rvar
@@ -411,13 +430,16 @@ plot.mnl <- function(
   plot_list <- list()
 
   if ("dist" %in% plots) {
-    for (i in vars)
+    for (i in vars) {
       plot_list[[paste("dist_", i)]] <- select_at(model, .vars = i) %>%
         visualize(xvar = i, bins = 10, custom = TRUE)
+    }
   }
 
   if ("coef" %in% plots) {
-    if (length(evar) == 0 && !intercept) return("** Model contains only an intercept **")
+    if (length(evar) == 0 && !intercept) {
+      return("** Model contains only an intercept **")
+    }
 
     yl <- {
       if (sum(c("standardize", "center") %in% x$check) == 2) {
@@ -436,7 +458,7 @@ plot.mnl <- function(
       ci_tab <- apply(ci_tab, 2, rbind)
       color <- "level"
     } else {
-      color = NULL
+      color <- NULL
     }
     ci_tab <- as.data.frame(ci_tab, stringsAsFactors = FALSE) %>%
       na.omit() %>%
@@ -451,15 +473,15 @@ plot.mnl <- function(
 
     nrCol <- 1
     plot_list[["coef"]] <- ggplot(ci_tab) +
-        geom_pointrange(aes_string(x = "label", y = "coefficient", ymin = "Low", ymax = "High", color = color), position = position_dodge(width = -0.6)) +
-        geom_hline(yintercept = 1, linetype = "dotdash", color = "blue") +
-        labs(y = yl, x = "") +
-        ## can't use coord_trans together with coord_flip
-        ## http://stackoverflow.com/a/26185278/1974918
-        scale_x_discrete(limits = rev(labels)) +
-        scale_y_continuous(breaks = c(0, 0.1, 0.2, 0.5, 1, 2, 5, 10), trans = "log") +
-        coord_flip() +
-        theme(axis.text.y = element_text(hjust = 0))
+      geom_pointrange(aes(x = .data$label, y = .data$coefficient, ymin = .data$Low, ymax = .data$High, color = .data[[color]]), position = position_dodge(width = -0.6)) +
+      geom_hline(yintercept = 1, linetype = "dotdash", color = "blue") +
+      labs(y = yl, x = "") +
+      ## can't use coord_trans together with coord_flip
+      ## http://stackoverflow.com/a/26185278/1974918
+      scale_x_discrete(limits = rev(labels)) +
+      scale_y_continuous(breaks = c(0, 0.1, 0.2, 0.5, 1, 2, 5, 10), trans = "log") +
+      coord_flip() +
+      theme(axis.text.y = element_text(hjust = 0))
   }
 
   if ("correlations" %in% plots) {
@@ -475,7 +497,9 @@ plot.mnl <- function(
       if (length(plot_list) == 1) plot_list[[1]] else plot_list
     } else {
       patchwork::wrap_plots(plot_list, ncol = nrCol) %>%
-        {if (shiny) . else print(.)}
+        {
+          if (shiny) . else print(.)
+        }
     }
   }
 }
@@ -506,13 +530,12 @@ plot.mnl <- function(
 #' @seealso \code{\link{summary.mnl}} to summarize results
 #'
 #' @export
-predict.mnl <- function(
-  object, pred_data = NULL, pred_cmd = "",
-  pred_names = "", dec = 3, envir = parent.frame(),
-  ...
-) {
-
-  if (is.character(object)) return(object)
+predict.mnl <- function(object, pred_data = NULL, pred_cmd = "",
+                        pred_names = "", dec = 3, envir = parent.frame(),
+                        ...) {
+  if (is.character(object)) {
+    return(object)
+  }
 
   ## ensure you have a name for the prediction dataset
   if (is.data.frame(pred_data)) {
@@ -542,7 +565,7 @@ predict.mnl <- function(
       # if (is.null(dim(pred_val))) pred_val <- t(pred_val)
       if (is.vector(pred_val)) pred_val <- t(pred_val)
       pred_val %<>% as.data.frame(stringsAsFactors = FALSE)
-      if (all(radiant.data::is_empty(pred_names))) pred_names <- colnames(pred_val)
+      if (all(is.empty(pred_names))) pred_names <- colnames(pred_val)
       pred_val %<>% select(1:min(ncol(pred_val), length(pred_names))) %>%
         set_colnames(pred_names)
     }
@@ -561,8 +584,9 @@ predict.mnl <- function(
 #' @param n Number of lines of prediction results to print. Use -1 to print all lines
 #'
 #' @export
-print.mnl.predict <- function(x, ..., n = 10)
+print.mnl.predict <- function(x, ..., n = 10) {
   print_predict_model(x, ..., n = n, header = "Multinomial logistic regression (MNL)", lev = attr(x, "radiant_lev"))
+}
 
 #' Plot method for mnl.predict function
 #'
@@ -585,24 +609,28 @@ print.mnl.predict <- function(x, ..., n = 10)
 #'
 #' @seealso \code{\link{predict.mnl}} to generate predictions
 #'
+#' @importFrom rlang .data
+#'
 #' @export
-plot.mnl.predict <- function(
-  x, xvar = "", facet_row = ".", facet_col = ".",
-  color = ".class", ...
-) {
+plot.mnl.predict <- function(x, xvar = "", facet_row = ".", facet_col = ".",
+                             color = ".class", ...) {
 
   ## should work with req in regress_ui but doesn't
-  if (radiant.data::is_empty(xvar)) return(invisible())
+  if (is.empty(xvar)) {
+    return(invisible())
+  }
 
   if (facet_col != "." && facet_row == facet_col) {
     return("The same variable cannot be used for both Facet row and Facet column")
   }
 
-  if (is.character(x)) return(x)
+  if (is.character(x)) {
+    return(x)
+  }
 
   pvars <- base::setdiff(attr(x, "radiant_vars"), attr(x, "radiant_evar"))
   rvar <- attr(x, "radiant_rvar")
-  x %<>% gather(".class", "Prediction", !! pvars)
+  x %<>% gather(".class", "Prediction", !!pvars)
 
   byvar <- c(xvar, color)
   if (facet_row != ".") byvar <- unique(c(byvar, facet_row))
@@ -611,7 +639,7 @@ plot.mnl.predict <- function(
   tmp <- group_by_at(x, .vars = byvar) %>%
     select_at(.vars = c(byvar, "Prediction")) %>%
     summarise_all(mean)
-  p <- ggplot(tmp, aes_string(x = xvar, y = "Prediction", color = color, group = color)) +
+  p <- ggplot(tmp, aes(x = .data[[xvar]], y = .data$Prediction, color = .data[[color]], group = .data[[color]])) +
     geom_line()
 
   if (facet_row != "." || facet_col != ".") {
@@ -654,7 +682,7 @@ store.mnl.predict <- function(dataset, object, name = NULL, ...) {
   # df <- as.vector(object[, pvars])
   df <- object[, pvars, drop = FALSE] %>% mutate(across(everything(), as.vector))
 
-  if (radiant.data::is_empty(name)) {
+  if (is.empty(name)) {
     name <- pvars
   } else {
     ## gsub needed because trailing/leading spaces may be added to the variable name
@@ -670,4 +698,4 @@ store.mnl.predict <- function(dataset, object, name = NULL, ...) {
   pred[indr$ind, ] <- df
   dataset[, name] <- pred
   dataset
-}
+}
\ No newline at end of file
