@@ -7,6 +7,8 @@
 #' @param evar Explanatory variables in the model
 #' @param laplace Positive double controlling Laplace smoothing. The default (0) disables Laplace smoothing.
 #' @param data_filter Expression entered in, e.g., Data > View to filter the dataset in Radiant. The expression should be a string (e.g., "price > 10000")
+#' @param arr Expression to arrange (sort) the data on (e.g., "color, desc(price)")
+#' @param rows Rows to select from the specified dataset
 #' @param envir Environment to extract data from
 #'
 #' @return A list with all variables defined in nb as an object of class nb
@@ -22,18 +24,16 @@
 #' @importFrom e1071 naiveBayes
 #'
 #' @export
-nb <- function(
-  dataset, rvar, evar, laplace = 0, 
-  data_filter = "", envir = parent.frame()
-) {
-
+nb <- function(dataset, rvar, evar, laplace = 0,
+               data_filter = "", arr = "", rows = NULL,
+               envir = parent.frame()) {
   if (rvar %in% evar) {
     return("Response variable contained in the set of explanatory variables.\nPlease update model specification." %>%
       add_class("nb"))
   }
 
   df_name <- if (!is_string(dataset)) deparse(substitute(dataset)) else dataset
-  dataset <- get_data(dataset, c(rvar, evar), filt = data_filter, envir = envir)
+  dataset <- get_data(dataset, c(rvar, evar), filt = data_filter, arr = arr, rows = rows, envir = envir)
 
   not_vary <- colnames(dataset)[summarise_all(dataset, does_vary) == FALSE]
   if (length(not_vary) > 0) {
@@ -87,13 +87,21 @@ nb <- function(
 #'
 #' @export
 summary.nb <- function(object, dec = 3, ...) {
-  if (is.character(object)) return(object)
+  if (is.character(object)) {
+    return(object)
+  }
 
   cat("Naive Bayes Classifier")
   cat("\nData                 :", object$df_name)
-  if (!radiant.data::is_empty(object$data_filter)) {
+  if (!is.empty(object$data_filter)) {
     cat("\nFilter               :", gsub("\\n", "", object$data_filter))
   }
+  if (!is.empty(object$arr)) {
+    cat("\nArrange              :", gsub("\\n", "", object$arr))
+  }
+  if (!is.empty(object$rows)) {
+    cat("\nSlice                :", gsub("\\n", "", object$rows))
+  }
   cat("\nResponse variable    :", object$rvar)
   cat("\nLevels               :", paste0(object$lev, collapse = ", "), "in", object$rvar)
   cat("\nExplanatory variables:", paste0(object$evar, collapse = ", "))
@@ -101,7 +109,10 @@ summary.nb <- function(object, dec = 3, ...) {
   cat("\nNr obs               :", format_nr(nrow(object$model$model), dec = 0), "\n")
 
   cat("\nA-priori probabilities:\n")
-  apriori <- object$model$apriori %>% {. / sum(.)}
+  apriori <- object$model$apriori %>%
+    {
+      . / sum(.)
+    }
   names(dimnames(apriori))[1] <- object$rvar
   print(round(apriori, 3))
 
@@ -136,8 +147,12 @@ summary.nb <- function(object, dec = 3, ...) {
 #'
 #' @export
 plot.nb <- function(x, plots = "correlations", lev = "All levels", nrobs = 1000, ...) {
-  if (is.character(x)) return(x)
-  if (radiant.data::is_empty(plots[1])) return(invisible())
+  if (is.character(x)) {
+    return(x)
+  }
+  if (is.empty(plots[1])) {
+    return(invisible())
+  }
 
   rvar <- x$model$model[[1]]
 
@@ -183,7 +198,7 @@ plot.nb <- function(x, plots = "correlations", lev = "All levels", nrobs = 1000,
     colnames(vimp) <- names(evar)
     vimp$Predict <- apply(cmb, 2, paste0, collapse = " vs ")
     vimp$Predict <- factor(vimp$Predict, levels = unique(rev(vimp$Predict)))
-    vimp <- gather(vimp, "vars", "auc", !! colnames(evar), factor_key = TRUE)
+    vimp <- gather(vimp, "vars", "auc", !!colnames(evar), factor_key = TRUE)
 
     p <- visualize(vimp, yvar = "auc", xvar = "Predict", type = "bar", fill = "vars", custom = TRUE) +
       guides(fill = guide_legend(title = "")) +
@@ -221,13 +236,12 @@ plot.nb <- function(x, plots = "correlations", lev = "All levels", nrobs = 1000,
 #' @seealso \code{\link{summary.nb}} to summarize results
 #'
 #' @export
-predict.nb <- function(
-  object, pred_data = NULL, pred_cmd = "",
-  pred_names = "", dec = 3, envir = parent.frame(), 
-  ...
-) {
-
-  if (is.character(object)) return(object)
+predict.nb <- function(object, pred_data = NULL, pred_cmd = "",
+                       pred_names = "", dec = 3, envir = parent.frame(),
+                       ...) {
+  if (is.character(object)) {
+    return(object)
+  }
 
   ## ensure you have a name for the prediction dataset
   if (is.data.frame(pred_data)) {
@@ -255,7 +269,7 @@ predict.nb <- function(
 
     if (!inherits(pred_val, "try-error")) {
       pred_val %<>% as.data.frame(stringsAsFactors = FALSE)
-      if (all(radiant.data::is_empty(pred_names))) pred_names <- colnames(pred_val)
+      if (all(is.empty(pred_names))) pred_names <- colnames(pred_val)
       pred_val %<>% select(1:min(ncol(pred_val), length(pred_names))) %>%
         set_colnames(pred_names)
     }
@@ -274,8 +288,9 @@ predict.nb <- function(
 #' @param n Number of lines of prediction results to print. Use -1 to print all lines
 #'
 #' @export
-print.nb.predict <- function(x, ..., n = 10)
+print.nb.predict <- function(x, ..., n = 10) {
   print_predict_model(x, ..., n = n, header = "Naive Bayes Classifier", lev = attr(x, "radiant_lev"))
+}
 
 #' Plot method for nb.predict function
 #'
@@ -298,24 +313,28 @@ print.nb.predict <- function(x, ..., n = 10)
 #'
 #' @seealso \code{\link{predict.nb}} to generate predictions
 #'
+#' @importFrom rlang .data
+#'
 #' @export
-plot.nb.predict <- function(
-  x, xvar = "", facet_row = ".", facet_col = ".",
-  color = ".class", ...
-) {
+plot.nb.predict <- function(x, xvar = "", facet_row = ".", facet_col = ".",
+                            color = ".class", ...) {
 
   ## should work with req in regress_ui but doesn't
-  if (radiant.data::is_empty(xvar)) return(invisible())
+  if (is.empty(xvar)) {
+    return(invisible())
+  }
 
   if (facet_col != "." && facet_row == facet_col) {
     return("The same variable cannot be used for both Facet row and Facet column")
   }
 
-  if (is.character(x)) return(x)
+  if (is.character(x)) {
+    return(x)
+  }
 
   pvars <- base::setdiff(attr(x, "radiant_vars"), attr(x, "radiant_evar"))
   rvar <- attr(x, "radiant_rvar")
-  x %<>% gather(".class", "Prediction", !! pvars)
+  x %<>% gather(".class", "Prediction", !!pvars)
 
   byvar <- c(xvar, color)
   if (facet_row != ".") byvar <- unique(c(byvar, facet_row))
@@ -324,7 +343,7 @@ plot.nb.predict <- function(
   tmp <- group_by_at(x, .vars = byvar) %>%
     select_at(.vars = c(byvar, "Prediction")) %>%
     summarise_all(mean)
-  p <- ggplot(tmp, aes_string(x = xvar, y = "Prediction", color = color, group = color)) +
+  p <- ggplot(tmp, aes(x = .data[[xvar]], y = .data$Prediction, color = .data[[color]], group = .data[[color]])) +
     geom_line()
 
   if (facet_row != "." || facet_col != ".") {
@@ -362,7 +381,7 @@ store.nb.predict <- function(dataset, object, name = NULL, ...) {
   # df <- as.vector(object[, pvars])
   df <- object[, pvars, drop = FALSE] %>% mutate(across(everything(), as.vector))
 
-  if (radiant.data::is_empty(name)) {
+  if (is.empty(name)) {
     name <- pvars
   } else {
     ## gsub needed because trailing/leading spaces may be added to the variable name
@@ -379,4 +398,4 @@ store.nb.predict <- function(dataset, object, name = NULL, ...) {
 
   dataset[, name] <- pred
   dataset
-}
+}
\ No newline at end of file
