@@ -24,6 +24,8 @@ mnl_args <- as.list(formals(mnl))
 mnl_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   mnl_args$data_filter <- if (input$show_filter) input$data_filter else ""
+  mnl_args$arr <- if (input$show_filter) input$data_arrange else ""
+  mnl_args$rows <- if (input$show_filter) input$data_rows else ""
   mnl_args$dataset <- input$dataset
   for (i in r_drop(names(mnl_args))) {
     mnl_args[[i]] <- input[[paste0("mnl_", i)]]
@@ -219,8 +221,8 @@ output$ui_mnl_show_interactions <- renderUI({
 output$ui_mnl_int <- renderUI({
   choices <- character(0)
   if (isolate("mnl_show_interactions" %in% names(input)) &&
-    radiant.data::is_empty(input$mnl_show_interactions)) {
-  } else if (radiant.data::is_empty(input$mnl_show_interactions)) {
+    is.empty(input$mnl_show_interactions)) {
+  } else if (is.empty(input$mnl_show_interactions)) {
     return()
   } else {
     vars <- input$mnl_evar
@@ -423,7 +425,7 @@ mnl_plot <- reactive({
   if (mnl_available() != "available") {
     return()
   }
-  if (radiant.data::is_empty(input$mnl_plots, "none")) {
+  if (is.empty(input$mnl_plots, "none")) {
     return()
   }
 
@@ -546,13 +548,13 @@ mnl_available <- reactive({
   if (mnl_available() != "available") {
     return(mnl_available())
   }
-  if (radiant.data::is_empty(input$mnl_predict, "none")) {
+  if (is.empty(input$mnl_predict, "none")) {
     return("** Select prediction input **")
   }
-  if ((input$mnl_predict == "data" || input$mnl_predict == "datacmd") && radiant.data::is_empty(input$mnl_pred_data)) {
+  if ((input$mnl_predict == "data" || input$mnl_predict == "datacmd") && is.empty(input$mnl_pred_data)) {
     return("** Select data for prediction **")
   }
-  if (input$mnl_predict == "cmd" && radiant.data::is_empty(input$mnl_pred_cmd)) {
+  if (input$mnl_predict == "cmd" && is.empty(input$mnl_pred_cmd)) {
     return("** Enter prediction commands **")
   }
 
@@ -573,7 +575,7 @@ mnl_available <- reactive({
   req(
     pressed(input$mnl_run), input$mnl_pred_plot,
     available(input$mnl_xvar),
-    !radiant.data::is_empty(input$mnl_predict, "none")
+    !is.empty(input$mnl_predict, "none")
   )
 
   withProgress(message = "Generating prediction plot", value = 1, {
@@ -584,7 +586,7 @@ mnl_available <- reactive({
 .plot_mnl <- reactive({
   if (not_pressed(input$mnl_run)) {
     return("** Press the Estimate button to estimate the model **")
-  } else if (radiant.data::is_empty(input$mnl_plots, "none")) {
+  } else if (is.empty(input$mnl_plots, "none")) {
     return("Please select a mnl regression plot from the drop-down menu")
   } else if (mnl_available() != "available") {
     return(mnl_available())
@@ -605,16 +607,17 @@ mnl_report <- function() {
   inp_out <- list("", "")
   inp_out[[1]] <- clean_args(mnl_sum_inputs(), mnl_sum_args[-1])
   figs <- FALSE
-  if (!radiant.data::is_empty(input$mnl_plots, "none")) {
-    inp_out[[2]] <- clean_args(mnl_plot_inputs(), mnl_plot_args[-1])
+  if (!is.empty(input$mnl_plots, "none")) {
+    inp <- check_plot_inputs(mnl_plot_inputs())
+    inp_out[[2]] <- clean_args(inp, mnl_plot_args[-1])
     inp_out[[2]]$custom <- FALSE
     outputs <- c(outputs, "plot")
     figs <- TRUE
   }
 
-  if (!radiant.data::is_empty(input$mnl_store_res_name)) {
+  if (!is.empty(input$mnl_store_res_name)) {
     name <- input$mnl_store_res_name
-    if (!radiant.data::is_empty(name)) {
+    if (!is.empty(name)) {
       name <- unlist(strsplit(name, "(\\s*,\\s*|\\s*;\\s*)")) %>%
         fix_names() %T>%
         updateTextInput(session, "mnl_store_res_name", value = .) %>%
@@ -628,17 +631,17 @@ mnl_report <- function() {
     xcmd <- ""
   }
 
-  if (!radiant.data::is_empty(input$mnl_predict, "none") &&
-    (!radiant.data::is_empty(input$mnl_pred_data) || !radiant.data::is_empty(input$mnl_pred_cmd))) {
+  if (!is.empty(input$mnl_predict, "none") &&
+    (!is.empty(input$mnl_pred_data) || !is.empty(input$mnl_pred_cmd))) {
     pred_args <- clean_args(mnl_pred_inputs(), mnl_pred_args[-1])
 
-    if (!radiant.data::is_empty(pred_args$pred_cmd)) {
-      pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";")[[1]]
+    if (!is.empty(pred_args$pred_cmd)) {
+      pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";\\s*")[[1]]
     } else {
       pred_args$pred_cmd <- NULL
     }
 
-    if (!radiant.data::is_empty(pred_args$pred_data)) {
+    if (!is.empty(pred_args$pred_data)) {
       pred_args$pred_data <- as.symbol(pred_args$pred_data)
     } else {
       pred_args$pred_data <- NULL
@@ -650,7 +653,7 @@ mnl_report <- function() {
     xcmd <- paste0(xcmd, "print(pred, n = 10)")
     if (input$mnl_predict %in% c("data", "datacmd")) {
       name <- input$mnl_store_pred_name
-      if (!radiant.data::is_empty(name)) {
+      if (!is.empty(name)) {
         name <- unlist(strsplit(input$mnl_store_pred_name, "(\\s*,\\s*|\\s*;\\s*)")) %>%
           fix_names() %>%
           deparse(., control = getOption("dctrl"), width.cutoff = 500L)
@@ -663,7 +666,7 @@ mnl_report <- function() {
 
     # xcmd <- paste0(xcmd, "\n# write.csv(pred, file = \"~/mnl_predictions.csv\", row.names = FALSE)")
 
-    if (input$mnl_pred_plot && !radiant.data::is_empty(input$mnl_xvar)) {
+    if (input$mnl_pred_plot && !is.empty(input$mnl_xvar)) {
       inp_out[[3 + figs]] <- clean_args(mnl_pred_plot_inputs(), mnl_pred_plot_args[-1])
       inp_out[[3 + figs]]$result <- "pred"
       outputs <- c(outputs, "plot")
@@ -700,7 +703,7 @@ observeEvent(input$mnl_store_res, {
 })
 
 observeEvent(input$mnl_store_pred, {
-  req(!radiant.data::is_empty(input$mnl_pred_data), pressed(input$mnl_run))
+  req(!is.empty(input$mnl_pred_data), pressed(input$mnl_run))
   pred <- .predict_mnl()
   if (is.null(pred)) {
     return()
